## Package Installation
# (1)
install.packages("installr")

## Basic Object Creation
# (1)
a = 1; b = 2; c = "a"; d = "b"
a; b; c; d

## Memory Management
# (1)
ls()
ls.str()

# (2)
ls(pattern = "^b")

# (3)
rm(d)

## Use of Help
x = c(1, 3, 6, 8)

# (1)
??mean
mean(x)

# (2)
??variance
var(x)

??deviation
sd(x)

# (3)
??median
median(x)

# (4)
A = matrix(c(1, 2, 3, 4), 2, 2)
??determinant
det(A)

## Vectors
# (1)
x = numeric(10000)

# (2)
y = character(10000)

# (3)
x = c(1.1, -1, 0, 1, 3.45)

# (4)
xnorm = rnorm(100, 1, 1); xnorm

# (5)
sum(xnorm > 1)
# Alternatively:
length(xnorm[xnorm > 1])

# (6)
y = rpois(100, 2); y

# (7)
xnorm[98:100]

# (8)
xnorm[seq(1, 100, 2)]

# (9)
xnorm[xnorm > 5] = 5; xnorm

## Matrices
# (1)
diag(5)

# (2)
A = matrix(rnorm(25, 2, 1), 5, 5); A

# (3)
dim(A)

# (4)
sum(A > 3)
# Alternatively:
length(A[A > 3])

# (5)
A[A <= 3] = 0; A[A > 3] = 1; A
# Alternatively:
A = matrix(as.numeric(A > 3), 5, 5); A

# (6)
A[,1] = -1; A

# (7)
rownames(A) = paste("R", 1:5, sep = "")
colnames(A) = paste("C", 1:5, sep = "")
dimnames(A)

## Data Frames
# (1)
D1 = data.frame(numbers = 1:6, letters = letters[1:6]); D1
sapply(D1, FUN = mode)

D2 = data.frame(numbers = 1:6, letters = letters[1:6], stringsAsFactors = FALSE); D2
sapply(D2, FUN = mode)

# (2)
D1$letters
D1[,2]

D2$letters
D2[,2]

# (3)
E = data.frame(uniform = runif(6, 0, 1), letters = letters[1:3]); E

# (4)
F = data.frame(geometric = rgeom(5, 0.5), letters = letters[1:3]); F

# (5)
G = data.frame(c(1, 3, 6, 8), c("b", "d", "g", "i"), c(TRUE, FALSE, FALSE, TRUE), stringsAsFactors = FALSE)
colnames(G) = c("numbers", "letters", "boolean"); G
sapply(G, FUN = mode)

# (6)
H = as.matrix(G); H
apply(H, MARGIN = 2, FUN = mode)

G = as.list(G); G

## Lists
# (1)
G$boolean
G[[3]]

# (2)
sapply(G, FUN = mode)
sapply(G, FUN = length)

# (3)
G[[1]] = mean(G[[1]]); G

# (4)
G = as.data.frame(G); G

## File Reading
df1 = read.table("MyTable_1.txt"); df1
df2 = read.table("MyTable_2.txt", header = TRUE); df2
df3 = read.table("MyTable_3.txt", sep = ","); df3

## Window Partitioning
windows()
layout(matrix(c(1, 2, 3, 3), 2, 2))
layout.show(3)

windows()
layout(matrix(c(1, 2, 2, 3, 3, 4), 3, 2))
layout.show(4)

## Plots
# (1)
mat1 = matrix(rnorm(200, 0, 1), 100, 2)
mat2 = matrix(rnorm(200, 1, 0.5), 100, 2)

# (2)
windows()
plot(mat1)
windows()
plot(mat2)

windows()
plot(mat1, col = "red")
points(mat2, col = "blue")

# (3)
xmin = min(mat1[,1], mat2[,1])
xmax = max(mat1[,1], mat2[,1])
ymin = min(mat1[,2], mat2[,2])
ymax = max(mat1[,2], mat2[,2])
windows()
plot(mat1, col = "red", xlim = c(xmin, xmax), ylim = c(ymin, ymax))
points(mat2, col = "blue")

# (4)
windows()
plot(mat1, col = "blue", pch = 8, xlim = c(xmin, xmax), ylim = c(ymin, ymax), xlab = "X1", ylab = "X2", main = "Scatterplot of the Data")
points(mat2, col = "purple", pch = 21, bg = "red")
